@@ -12,6 +12,8 @@
 SYSTEMTESTTOP=..
 . $SYSTEMTESTTOP/conf.sh
 
+$SHELL clean.sh
+
 cat <<EOF >ns1/named.conf
 options {
 	query-source address 10.53.0.1;
@@ -37,7 +39,6 @@ EOF
 
 copy_setports ns3/named.conf.in ns3/named.conf
 copy_setports ns4/named.conf.in ns4/named.conf
-copy_setports ns5/named.conf.in ns5/named.conf
 
 # Setup initial db files for ns3
 cp ns3/mytest0.db ns3/mytest.db
