@@ -106,25 +106,40 @@ foreach my $name (@ns) {
 @ns = wait_for_servers(60, @ns);
 
 foreach my $name(@ans) {
-	stop_signal($name, "TERM");
+	stop_signal($name, "TERM", 1);
 }
 
 @ans = wait_for_servers(60, @ans);
 
 # Pass 3: SIGABRT
-foreach my $name (@ns, @ans) {
+foreach my $name (@ns) {
 	print "I:$test:$name didn't die when sent a SIGTERM\n";
 	stop_signal($name, "ABRT");
 	$errors = 1;
 }
+foreach my $name (@ans) {
+	print "I:$test:$name didn't die when sent a SIGTERM\n";
+	stop_signal($name, "ABRT", 1);
+	$errors = 1;
+}
 
 exit($errors);
 
 # Subroutines
 
+# Return the full path to a given server's lock file.
+sub server_lock_file {
+	my ( $server ) = @_;
+
+	return $testdir . "/" . $server . "/named.lock" if ($server =~ /^ns/);
+	return if ($server =~ /^ans/);
+
+	die "Unknown server type $server\n";
+}
+
 # Return the full path to a given server's PID file.
 sub server_pid_file {
-	my($server) = @_;
+	my ( $server ) = @_;
 
 	return $testdir . "/" . $server . "/named.pid" if ($server =~ /^ns/);
 	return $testdir . "/" . $server . "/ans.pid" if ($server =~ /^ans/);
@@ -184,11 +199,15 @@ sub server_died {
 }
 
 sub send_signal {
-	my ( $signal, $pid ) = @_;
+	my ( $signal, $pid, $ans ) = @_;
+
+	if (! defined $ans) {
+		$ans = 0;
+	}
 
 	my $result = 0;
 
-	if ($^O eq 'cygwin') {
+	if (!$ans && ($^O eq 'cygwin' || $^O eq 'msys')) {
 		my $killout = `/bin/kill -f -$signal $pid 2>&1`;
 		chomp($killout);
 		$result = 1 if ($killout eq '');
@@ -200,7 +219,10 @@ sub send_signal {
 
 # Stop a server by sending a signal to it.
 sub stop_signal {
-	my ( $server, $signal ) = @_;
+	my ( $server, $signal, $ans ) = @_;
+	if (! defined $ans) {
+		$ans = 0;
+	}
 
 	my $pid_file = server_pid_file($server);
 	my $pid = read_pid($pid_file);
@@ -208,7 +230,7 @@ sub stop_signal {
 	return unless defined($pid);
 
 	# Send signal to the server, and bail out if signal can't be sent
-	if (send_signal($signal, $pid) != 1) {
+	if (send_signal($signal, $pid, $ans) != 1) {
 		server_died($server, $signal);
 		return;
 	}
@@ -216,7 +238,7 @@ sub stop_signal {
 	return;
 }
 
-sub clean_pid_file {
+sub pid_file_exists {
 	my ( $server ) = @_;
 
 	my $pid_file = server_pid_file($server);
@@ -224,7 +246,25 @@ sub clean_pid_file {
 
 	return unless defined($pid);
 
-	return if (send_signal(0, $pid) == 0);
+	# If we're here, the PID file hasn't been cleaned up yet
+	if (send_signal(0, $pid) == 0) {
+		# XXX: on windows this is likely to result in a
+		# false positive, so don't bother reporting the error.
+		if (!defined($ENV{'CYGWIN'})) {
+			print "I:$test:$server crashed on shutdown\n";
+			$errors = 1;
+		}
+		return;
+	}
+
+	return $server;
+}
+
+sub lock_file_exists {
+	my ( $server ) = @_;
+	my $lock_file = server_lock_file($server);
+
+	return unless defined($lock_file) && -f $lock_file;
 
 	return $server;
 }
@@ -236,7 +276,7 @@ sub wait_for_servers {
 		sleep 1 if (@servers > 0);
 		@servers =
 			grep { defined($_) }
-			map  { clean_pid_file($_) } @servers;
+			map  { pid_file_exists($_) || lock_file_exists($_) } @servers;
 		$timeout--;
 	}
 
