@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -24,7 +24,7 @@
 #include <isc/result.h>
 #include <isc/util.h>
 
-#ifdef ISC_PLATFORM_USEBACKTRACE
+#ifdef USE_BACKTRACE
 /*
  * Getting a back trace of a running process is tricky and highly platform
  * dependent.  Our current approach is as follows:
@@ -52,9 +52,9 @@
 #else
 #define BACKTRACE_DISABLED
 #endif  /* HAVE_LIBCTRACE */
-#else	/* !ISC_PLATFORM_USEBACKTRACE */
+#else	/* USE_BACKTRACE */
 #define BACKTRACE_DISABLED
-#endif	/* ISC_PLATFORM_USEBACKTRACE */
+#endif	/* USE_BACKTRACE */
 
 #ifdef BACKTRACE_LIBC
 isc_result_t
