@@ -1,15 +1,17 @@
 /*
- * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
+ * Portions Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * SPDX-License-Identifier: MPL-2.0 AND BSD-3-Clause
-
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 /*
- * Copyright (C) 1987, 1993, 1994 The Regents of the University of California.
+ * Copyright (c) 1987, 1993, 1994
+ *	The Regents of the University of California.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -34,11 +36,9 @@
  * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
- *
- * See the COPYRIGHT file distributed with this work for additional
- * information regarding copyright ownership.
  */
 
+
 /*! \file
  * This file was adapted from the NetBSD project's source tree, RCS ID:
  *    NetBSD: getopt.c,v 1.15 1999/09/20 04:39:37 lukem Exp
@@ -47,41 +47,44 @@
  * and format in the ISC coding style.
  */
 
+#include <config.h>
+
 #include <stdbool.h>
 #include <stdio.h>
 
 #include <isc/commandline.h>
 #include <isc/mem.h>
+#include <isc/print.h>
 #include <isc/string.h>
 #include <isc/util.h>
 
 /*% Index into parent argv vector. */
-int isc_commandline_index = 1;
+LIBISC_EXTERNAL_DATA int isc_commandline_index = 1;
 /*% Character checked for validity. */
-int isc_commandline_option;
+LIBISC_EXTERNAL_DATA int isc_commandline_option;
 /*% Argument associated with option. */
-char *isc_commandline_argument;
+LIBISC_EXTERNAL_DATA char *isc_commandline_argument;
 /*% For printing error messages. */
-char *isc_commandline_progname;
+LIBISC_EXTERNAL_DATA char *isc_commandline_progname;
 /*% Print error messages. */
-bool isc_commandline_errprint = true;
+LIBISC_EXTERNAL_DATA bool isc_commandline_errprint = true;
 /*% Reset processing. */
-bool isc_commandline_reset = true;
+LIBISC_EXTERNAL_DATA bool isc_commandline_reset = true;
 
 static char endopt = '\0';
 
-#define BADOPT '?'
-#define BADARG ':'
-#define ENDOPT &endopt
+#define	BADOPT	'?'
+#define	BADARG	':'
+#define ENDOPT  &endopt
 
 /*!
  * getopt --
  *	Parse argc/argv argument vector.
  */
 int
-isc_commandline_parse(int argc, char *const *argv, const char *options) {
+isc_commandline_parse(int argc, char * const *argv, const char *options) {
 	static char *place = ENDOPT;
-	const char *option; /* Index into *options of option. */
+	const char *option;		/* Index into *options of option. */
 
 	REQUIRE(argc >= 0 && argv != NULL && options != NULL);
 
@@ -95,13 +98,11 @@ isc_commandline_parse(int argc, char *const *argv, const char *options) {
 			isc_commandline_reset = false;
 		}
 
-		if (isc_commandline_progname == NULL) {
+		if (isc_commandline_progname == NULL)
 			isc_commandline_progname = argv[0];
-		}
 
 		if (isc_commandline_index >= argc ||
-		    *(place = argv[isc_commandline_index]) != '-')
-		{
+		    *(place = argv[isc_commandline_index]) != '-') {
 			/*
 			 * Index out of range or points to non-option.
 			 */
@@ -129,15 +130,13 @@ isc_commandline_parse(int argc, char *const *argv, const char *options) {
 	 * distinguish ':' from the argument specifier in the options string.
 	 */
 	if (isc_commandline_option == ':' || option == NULL) {
-		if (*place == '\0') {
+		if (*place == '\0')
 			isc_commandline_index++;
-		}
 
-		if (isc_commandline_errprint && *options != ':') {
+		if (isc_commandline_errprint && *options != ':')
 			fprintf(stderr, "%s: illegal option -- %c\n",
 				isc_commandline_progname,
 				isc_commandline_option);
-		}
 
 		return (BADOPT);
 	}
@@ -151,24 +150,26 @@ isc_commandline_parse(int argc, char *const *argv, const char *options) {
 		/*
 		 * Skip to next argv if at the end of the current argv.
 		 */
-		if (*place == '\0') {
+		if (*place == '\0')
 			++isc_commandline_index;
-		}
+
 	} else {
 		/*
 		 * Option needs an argument.
 		 */
-		if (*place != '\0') {
+		if (*place != '\0')
 			/*
 			 * Option is in this argv, -D1 style.
 			 */
 			isc_commandline_argument = place;
-		} else if (argc > ++isc_commandline_index) {
+
+		else if (argc > ++isc_commandline_index)
 			/*
 			 * Option is next argv, -D 1 style.
 			 */
 			isc_commandline_argument = argv[isc_commandline_index];
-		} else {
+
+		else {
 			/*
 			 * Argument needed, but no more argv.
 			 */
@@ -178,17 +179,13 @@ isc_commandline_parse(int argc, char *const *argv, const char *options) {
 			 * Silent failure with "missing argument" return
 			 * when ':' starts options string, per historical spec.
 			 */
-			if (*options == ':') {
+			if (*options == ':')
 				return (BADARG);
-			}
 
-			if (isc_commandline_errprint) {
-				fprintf(stderr,
-					"%s: option requires an argument -- "
-					"%c\n",
+			if (isc_commandline_errprint)
+				fprintf(stderr, "%s: option requires an argument -- %c\n",
 					isc_commandline_progname,
 					isc_commandline_option);
-			}
 
 			return (BADOPT);
 		}
@@ -206,19 +203,21 @@ isc_commandline_parse(int argc, char *const *argv, const char *options) {
 
 isc_result_t
 isc_commandline_strtoargv(isc_mem_t *mctx, char *s, unsigned int *argcp,
-			  char ***argvp, unsigned int n) {
+			  char ***argvp, unsigned int n)
+{
 	isc_result_t result;
 
-restart:
+ restart:
 	/* Discard leading whitespace. */
-	while (*s == ' ' || *s == '\t') {
+	while (*s == ' ' || *s == '\t')
 		s++;
-	}
 
 	if (*s == '\0') {
 		/* We have reached the end of the string. */
 		*argcp = n;
-		*argvp = isc_mem_cget(mctx, n, sizeof(char *));
+		*argvp = isc_mem_get(mctx, n * sizeof(char *));
+		if (*argvp == NULL)
+			return (ISC_R_NOMEMORY);
 	} else {
 		char *p = s;
 		while (*p != ' ' && *p != '\t' && *p != '\0' && *p != '{') {
@@ -237,7 +236,7 @@ restart:
 			 */
 			while (*t != '\0') {
 				t++;
-				*(t - 1) = *t;
+				*(t-1) = *t;
 			}
 			while (*p != '\0' && *p != '}') {
 				p++;
@@ -248,15 +247,13 @@ restart:
 				p++;
 			}
 			/* normal case, no "grouping" */
-		} else if (*p != '\0') {
+		} else if (*p != '\0')
 			*p++ = '\0';
-		}
 
-		result = isc_commandline_strtoargv(mctx, p, argcp, argvp,
-						   n + 1);
-		if (result != ISC_R_SUCCESS) {
+		result = isc_commandline_strtoargv(mctx, p,
+						   argcp, argvp, n + 1);
+		if (result != ISC_R_SUCCESS)
 			return (result);
-		}
 		(*argvp)[n] = s;
 	}
 
