@@ -24,7 +24,6 @@
 #include <isc/file.h>
 #include <isc/lex.h>
 #include <isc/mem.h>
-#include <isc/msgs.h>
 #include <isc/parseint.h>
 #include <isc/print.h>
 #include <isc/stdio.h>
@@ -434,7 +433,7 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 			if (source->is_file) {
 				stream = source->input;
 
-#if defined(HAVE_FLOCKFILE) && defined(HAVE_GETCUNLOCKED)
+#if defined(HAVE_FLOCKFILE) && defined(HAVE_GETC_UNLOCKED)
 				c = getc_unlocked(stream);
 #else
 				c = getc(stream);
@@ -854,11 +853,9 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 			break;
 		default:
 			FATAL_ERROR(__FILE__, __LINE__,
-				    isc_msgcat_get(isc_msgcat, ISC_MSGSET_LEX,
-						   ISC_MSG_UNEXPECTEDSTATE,
-						   "Unexpected state %d"),
+				    "Unexpected state %d",
 				    state);
-			/* Does not return. */
+			ISC_UNREACHABLE();
 		}
 
 	} while (!done);
