@@ -13,10 +13,9 @@
 
 #if HAVE_CMOCKA
 
-#include <setjmp.h>
 #include <stdarg.h>
 #include <stddef.h>
-#include <stdlib.h>
+#include <setjmp.h>
 
 #include <string.h>
 #include <sys/errno.h>
@@ -25,7 +24,6 @@
 #include <cmocka.h>
 
 #include <isc/errno.h>
-#include <isc/print.h>
 #include <isc/result.h>
 #include <isc/util.h>
 
