@@ -15,17 +15,16 @@
 
 #include <stdarg.h>
 #include <stddef.h>
+#include <stdlib.h>
 #include <setjmp.h>
 #include <string.h>
 
 #define UNIT_TESTING
 #include <cmocka.h>
 
-#include <isc/print.h>
 #include <isc/result.h>
 #include <isc/util.h>
 
-#include <isccc/lib.h>
 #include <isccc/result.h>
 
 /*
